# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type
from telnyx.types.conferences import (
    ActionHoldResponse,
    ActionJoinResponse,
    ActionMuteResponse,
    ActionPlayResponse,
    ActionStopResponse,
    ActionLeaveResponse,
    ActionSpeakResponse,
    ActionUnholdResponse,
    ActionUnmuteResponse,
    ActionUpdateResponse,
    ActionSendDtmfResponse,
    ActionRecordStopResponse,
    ActionRecordPauseResponse,
    ActionRecordStartResponse,
    ActionRecordResumeResponse,
    ActionEndConferenceResponse,
    ActionGatherDtmfAudioResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestActions:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update(self, client: Telnyx) -> None:
        action = client.conferences.actions.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
        )
        assert_matches_type(ActionUpdateResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
            whisper_call_control_ids=[
                "v2:Sg1xxxQ_U3ixxxyXT_VDNI3xxxazZdg6Vxxxs4-GNYxxxVaJPOhFMRQ",
                "v2:qqpb0mmvd-ovhhBr0BUQQn0fld5jIboaaX3-De0DkqXHzbf8d75xkw",
            ],
        )
        assert_matches_type(ActionUpdateResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionUpdateResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionUpdateResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.update(
                id="",
                call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
                supervisor_role="whisper",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_end_conference(self, client: Telnyx) -> None:
        action = client.conferences.actions.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_end_conference_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
        )
        assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_end_conference(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_end_conference(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_end_conference(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.end_conference(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_gather_dtmf_audio(self, client: Telnyx) -> None:
        action = client.conferences.actions.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )
        assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_gather_dtmf_audio_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            audio_url="http://example.com/gather_prompt.wav",
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            gather_id="gather_id",
            initial_timeout_millis=10000,
            inter_digit_timeout_millis=3000,
            invalid_audio_url="invalid_audio_url",
            invalid_media_name="invalid_media_name",
            maximum_digits=4,
            maximum_tries=3,
            media_name="media_name",
            minimum_digits=1,
            stop_playback_on_dtmf=True,
            terminating_digit="#",
            timeout_millis=30000,
            valid_digits="0123456789",
        )
        assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_gather_dtmf_audio(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_gather_dtmf_audio(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_gather_dtmf_audio(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.gather_dtmf_audio(
                id="",
                call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_hold(self, client: Telnyx) -> None:
        action = client.conferences.actions.hold(
            id="id",
        )
        assert_matches_type(ActionHoldResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_hold_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.hold(
            id="id",
            audio_url="http://example.com/message.wav",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            media_name="my_media_uploaded_to_media_storage_api",
            region="US",
        )
        assert_matches_type(ActionHoldResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_hold(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.hold(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionHoldResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_hold(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.hold(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionHoldResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_hold(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.hold(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_join(self, client: Telnyx) -> None:
        action = client.conferences.actions.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )
        assert_matches_type(ActionJoinResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_join_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            beep_enabled="always",
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            end_conference_on_exit=True,
            hold=True,
            hold_audio_url="http://www.example.com/audio.wav",
            hold_media_name="my_media_uploaded_to_media_storage_api",
            mute=True,
            region="US",
            soft_end_conference_on_exit=True,
            start_conference_on_enter=True,
            supervisor_role="whisper",
            whisper_call_control_ids=[
                "v2:Sg1xxxQ_U3ixxxyXT_VDNI3xxxazZdg6Vxxxs4-GNYxxxVaJPOhFMRQ",
                "v2:qqpb0mmvd-ovhhBr0BUQQn0fld5jIboaaX3-De0DkqXHzbf8d75xkw",
            ],
        )
        assert_matches_type(ActionJoinResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_join(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionJoinResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_join(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionJoinResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_join(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.join(
                id="",
                call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_leave(self, client: Telnyx) -> None:
        action = client.conferences.actions.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
        )
        assert_matches_type(ActionLeaveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_leave_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
            beep_enabled="never",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
        )
        assert_matches_type(ActionLeaveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_leave(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionLeaveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_leave(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionLeaveResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_leave(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.leave(
                id="",
                call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_mute(self, client: Telnyx) -> None:
        action = client.conferences.actions.mute(
            id="id",
        )
        assert_matches_type(ActionMuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_mute_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.mute(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            region="US",
        )
        assert_matches_type(ActionMuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_mute(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.mute(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionMuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_mute(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.mute(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionMuteResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_mute(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.mute(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_play(self, client: Telnyx) -> None:
        action = client.conferences.actions.play(
            id="id",
        )
        assert_matches_type(ActionPlayResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_play_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.play(
            id="id",
            audio_url="http://www.example.com/sounds/greeting.wav",
            call_control_ids=["string"],
            loop="infinity",
            media_name="my_media_uploaded_to_media_storage_api",
            region="US",
        )
        assert_matches_type(ActionPlayResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_play(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.play(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionPlayResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_play(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.play(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionPlayResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_play(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.play(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_pause(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_pause(
            id="id",
        )
        assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_pause_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_pause(
            id="id",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            recording_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
        )
        assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_record_pause(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.record_pause(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_record_pause(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.record_pause(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_record_pause(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.record_pause(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_resume(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_resume(
            id="id",
        )
        assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_resume_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_resume(
            id="id",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            recording_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
        )
        assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_record_resume(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.record_resume(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_record_resume(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.record_resume(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_record_resume(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.record_resume(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_start(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_start(
            id="id",
            format="wav",
        )
        assert_matches_type(ActionRecordStartResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_start_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_start(
            id="id",
            format="wav",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            custom_file_name="my_recording_file_name",
            play_beep=True,
            region="US",
            trim="trim-silence",
        )
        assert_matches_type(ActionRecordStartResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_record_start(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.record_start(
            id="id",
            format="wav",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRecordStartResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_record_start(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.record_start(
            id="id",
            format="wav",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRecordStartResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_record_start(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.record_start(
                id="",
                format="wav",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_stop(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_stop(
            id="id",
        )
        assert_matches_type(ActionRecordStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_record_stop_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.record_stop(
            id="id",
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            recording_id="6e00ab49-9487-4364-8ad6-23965965afb2",
            region="US",
        )
        assert_matches_type(ActionRecordStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_record_stop(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.record_stop(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionRecordStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_record_stop(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.record_stop(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionRecordStopResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_record_stop(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.record_stop(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_dtmf(self, client: Telnyx) -> None:
        action = client.conferences.actions.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
        )
        assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_send_dtmf_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            duration_millis=250,
        )
        assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_send_dtmf(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_send_dtmf(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_send_dtmf(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.send_dtmf(
                id="",
                digits="1234#",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_speak(self, client: Telnyx) -> None:
        action = client.conferences.actions.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
        )
        assert_matches_type(ActionSpeakResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_speak_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            language="en-US",
            payload_type="text",
            region="US",
            voice_settings={
                "type": "elevenlabs",
                "api_key_ref": "my_elevenlabs_api_key",
            },
        )
        assert_matches_type(ActionSpeakResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_speak(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionSpeakResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_speak(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionSpeakResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_speak(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.speak(
                id="",
                payload="Say this to participants",
                voice="female",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_stop(self, client: Telnyx) -> None:
        action = client.conferences.actions.stop(
            id="id",
        )
        assert_matches_type(ActionStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_stop_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.stop(
            id="id",
            call_control_ids=["string"],
            region="US",
        )
        assert_matches_type(ActionStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_stop(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.stop(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_stop(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.stop(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionStopResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_stop(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.stop(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unhold(self, client: Telnyx) -> None:
        action = client.conferences.actions.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
        )
        assert_matches_type(ActionUnholdResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unhold_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            region="US",
        )
        assert_matches_type(ActionUnholdResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_unhold(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionUnholdResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_unhold(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionUnholdResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_unhold(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.unhold(
                id="",
                call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unmute(self, client: Telnyx) -> None:
        action = client.conferences.actions.unmute(
            id="id",
        )
        assert_matches_type(ActionUnmuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_unmute_with_all_params(self, client: Telnyx) -> None:
        action = client.conferences.actions.unmute(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            region="US",
        )
        assert_matches_type(ActionUnmuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_unmute(self, client: Telnyx) -> None:
        response = client.conferences.actions.with_raw_response.unmute(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = response.parse()
        assert_matches_type(ActionUnmuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_unmute(self, client: Telnyx) -> None:
        with client.conferences.actions.with_streaming_response.unmute(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = response.parse()
            assert_matches_type(ActionUnmuteResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_unmute(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.conferences.actions.with_raw_response.unmute(
                id="",
            )


class TestAsyncActions:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
        )
        assert_matches_type(ActionUpdateResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
            whisper_call_control_ids=[
                "v2:Sg1xxxQ_U3ixxxyXT_VDNI3xxxazZdg6Vxxxs4-GNYxxxVaJPOhFMRQ",
                "v2:qqpb0mmvd-ovhhBr0BUQQn0fld5jIboaaX3-De0DkqXHzbf8d75xkw",
            ],
        )
        assert_matches_type(ActionUpdateResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionUpdateResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.update(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            supervisor_role="whisper",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionUpdateResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.update(
                id="",
                call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
                supervisor_role="whisper",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_end_conference(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_end_conference_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
        )
        assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_end_conference(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_end_conference(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.end_conference(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionEndConferenceResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_end_conference(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.end_conference(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_gather_dtmf_audio(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )
        assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_gather_dtmf_audio_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            audio_url="http://example.com/gather_prompt.wav",
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            gather_id="gather_id",
            initial_timeout_millis=10000,
            inter_digit_timeout_millis=3000,
            invalid_audio_url="invalid_audio_url",
            invalid_media_name="invalid_media_name",
            maximum_digits=4,
            maximum_tries=3,
            media_name="media_name",
            minimum_digits=1,
            stop_playback_on_dtmf=True,
            terminating_digit="#",
            timeout_millis=30000,
            valid_digits="0123456789",
        )
        assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_gather_dtmf_audio(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_gather_dtmf_audio(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.gather_dtmf_audio(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionGatherDtmfAudioResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_gather_dtmf_audio(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.gather_dtmf_audio(
                id="",
                call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_hold(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.hold(
            id="id",
        )
        assert_matches_type(ActionHoldResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_hold_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.hold(
            id="id",
            audio_url="http://example.com/message.wav",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            media_name="my_media_uploaded_to_media_storage_api",
            region="US",
        )
        assert_matches_type(ActionHoldResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_hold(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.hold(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionHoldResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_hold(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.hold(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionHoldResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_hold(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.hold(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_join(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )
        assert_matches_type(ActionJoinResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_join_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            beep_enabled="always",
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            end_conference_on_exit=True,
            hold=True,
            hold_audio_url="http://www.example.com/audio.wav",
            hold_media_name="my_media_uploaded_to_media_storage_api",
            mute=True,
            region="US",
            soft_end_conference_on_exit=True,
            start_conference_on_enter=True,
            supervisor_role="whisper",
            whisper_call_control_ids=[
                "v2:Sg1xxxQ_U3ixxxyXT_VDNI3xxxazZdg6Vxxxs4-GNYxxxVaJPOhFMRQ",
                "v2:qqpb0mmvd-ovhhBr0BUQQn0fld5jIboaaX3-De0DkqXHzbf8d75xkw",
            ],
        )
        assert_matches_type(ActionJoinResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_join(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionJoinResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_join(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.join(
            id="id",
            call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionJoinResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_join(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.join(
                id="",
                call_control_id="v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_leave(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
        )
        assert_matches_type(ActionLeaveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_leave_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
            beep_enabled="never",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
        )
        assert_matches_type(ActionLeaveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_leave(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionLeaveResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_leave(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.leave(
            id="id",
            call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionLeaveResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_leave(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.leave(
                id="",
                call_control_id="c46e06d7-b78f-4b13-96b6-c576af9640ff",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_mute(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.mute(
            id="id",
        )
        assert_matches_type(ActionMuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_mute_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.mute(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            region="US",
        )
        assert_matches_type(ActionMuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_mute(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.mute(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionMuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_mute(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.mute(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionMuteResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_mute(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.mute(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_play(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.play(
            id="id",
        )
        assert_matches_type(ActionPlayResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_play_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.play(
            id="id",
            audio_url="http://www.example.com/sounds/greeting.wav",
            call_control_ids=["string"],
            loop="infinity",
            media_name="my_media_uploaded_to_media_storage_api",
            region="US",
        )
        assert_matches_type(ActionPlayResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_play(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.play(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionPlayResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_play(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.play(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionPlayResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_play(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.play(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_pause(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_pause(
            id="id",
        )
        assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_pause_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_pause(
            id="id",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            recording_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
        )
        assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_record_pause(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.record_pause(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_record_pause(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.record_pause(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRecordPauseResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_record_pause(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.record_pause(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_resume(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_resume(
            id="id",
        )
        assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_resume_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_resume(
            id="id",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            recording_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            region="US",
        )
        assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_record_resume(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.record_resume(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_record_resume(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.record_resume(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRecordResumeResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_record_resume(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.record_resume(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_start(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_start(
            id="id",
            format="wav",
        )
        assert_matches_type(ActionRecordStartResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_start_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_start(
            id="id",
            format="wav",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            custom_file_name="my_recording_file_name",
            play_beep=True,
            region="US",
            trim="trim-silence",
        )
        assert_matches_type(ActionRecordStartResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_record_start(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.record_start(
            id="id",
            format="wav",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRecordStartResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_record_start(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.record_start(
            id="id",
            format="wav",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRecordStartResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_record_start(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.record_start(
                id="",
                format="wav",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_stop(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_stop(
            id="id",
        )
        assert_matches_type(ActionRecordStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_record_stop_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.record_stop(
            id="id",
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            recording_id="6e00ab49-9487-4364-8ad6-23965965afb2",
            region="US",
        )
        assert_matches_type(ActionRecordStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_record_stop(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.record_stop(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionRecordStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_record_stop(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.record_stop(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionRecordStopResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_record_stop(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.record_stop(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_dtmf(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
        )
        assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_send_dtmf_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            client_state="aGF2ZSBhIG5pY2UgZGF5ID1d",
            duration_millis=250,
        )
        assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_send_dtmf(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_send_dtmf(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.send_dtmf(
            id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            digits="1234#",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionSendDtmfResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_send_dtmf(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.send_dtmf(
                id="",
                digits="1234#",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_speak(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
        )
        assert_matches_type(ActionSpeakResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_speak_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            command_id="891510ac-f3e4-11e8-af5b-de00688a4901",
            language="en-US",
            payload_type="text",
            region="US",
            voice_settings={
                "type": "elevenlabs",
                "api_key_ref": "my_elevenlabs_api_key",
            },
        )
        assert_matches_type(ActionSpeakResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_speak(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionSpeakResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_speak(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.speak(
            id="id",
            payload="Say this to participants",
            voice="female",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionSpeakResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_speak(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.speak(
                id="",
                payload="Say this to participants",
                voice="female",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_stop(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.stop(
            id="id",
        )
        assert_matches_type(ActionStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_stop_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.stop(
            id="id",
            call_control_ids=["string"],
            region="US",
        )
        assert_matches_type(ActionStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_stop(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.stop(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionStopResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_stop(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.stop(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionStopResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_stop(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.stop(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unhold(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
        )
        assert_matches_type(ActionUnholdResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unhold_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            region="US",
        )
        assert_matches_type(ActionUnholdResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_unhold(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionUnholdResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_unhold(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.unhold(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionUnholdResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_unhold(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.unhold(
                id="",
                call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unmute(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.unmute(
            id="id",
        )
        assert_matches_type(ActionUnmuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_unmute_with_all_params(self, async_client: AsyncTelnyx) -> None:
        action = await async_client.conferences.actions.unmute(
            id="id",
            call_control_ids=["v3:MdI91X4lWFEs7IgbBEOT9M4AigoY08M0WWZFISt1Yw2axZ_IiE4pqg"],
            region="US",
        )
        assert_matches_type(ActionUnmuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_unmute(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.conferences.actions.with_raw_response.unmute(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        action = await response.parse()
        assert_matches_type(ActionUnmuteResponse, action, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_unmute(self, async_client: AsyncTelnyx) -> None:
        async with async_client.conferences.actions.with_streaming_response.unmute(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            action = await response.parse()
            assert_matches_type(ActionUnmuteResponse, action, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_unmute(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.conferences.actions.with_raw_response.unmute(
                id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .rcs_capabilities import RcsCapabilities

__all__ = ["RcRetrieveCapabilitiesResponse"]


class RcRetrieveCapabilitiesResponse(BaseModel):
    data: Optional[RcsCapabilities] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel
from .sim_card_group_action import SimCardGroupAction

__all__ = ["ActionRemovePrivateWirelessGatewayResponse"]


class ActionRemovePrivateWirelessGatewayResponse(BaseModel):
    data: Optional[SimCardGroupAction] = None
    """This object represents a SIM card group action request.

    It allows tracking the current status of an operation that impacts the SIM card
    group and SIM card in it.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .rcs.rcs import (
    RcsResource,
    AsyncRcsResource,
    RcsResourceWithRawResponse,
    AsyncRcsResourceWithRawResponse,
    RcsResourceWithStreamingResponse,
    AsyncRcsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["MessagingResource", "AsyncMessagingResource"]


class MessagingResource(SyncAPIResource):
    @cached_property
    def rcs(self) -> RcsResource:
        return RcsResource(self._client)

    @cached_property
    def with_raw_response(self) -> MessagingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return MessagingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MessagingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return MessagingResourceWithStreamingResponse(self)


class AsyncMessagingResource(AsyncAPIResource):
    @cached_property
    def rcs(self) -> AsyncRcsResource:
        return AsyncRcsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncMessagingResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMessagingResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMessagingResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncMessagingResourceWithStreamingResponse(self)


class MessagingResourceWithRawResponse:
    def __init__(self, messaging: MessagingResource) -> None:
        self._messaging = messaging

    @cached_property
    def rcs(self) -> RcsResourceWithRawResponse:
        return RcsResourceWithRawResponse(self._messaging.rcs)


class AsyncMessagingResourceWithRawResponse:
    def __init__(self, messaging: AsyncMessagingResource) -> None:
        self._messaging = messaging

    @cached_property
    def rcs(self) -> AsyncRcsResourceWithRawResponse:
        return AsyncRcsResourceWithRawResponse(self._messaging.rcs)


class MessagingResourceWithStreamingResponse:
    def __init__(self, messaging: MessagingResource) -> None:
        self._messaging = messaging

    @cached_property
    def rcs(self) -> RcsResourceWithStreamingResponse:
        return RcsResourceWithStreamingResponse(self._messaging.rcs)


class AsyncMessagingResourceWithStreamingResponse:
    def __init__(self, messaging: AsyncMessagingResource) -> None:
        self._messaging = messaging

    @cached_property
    def rcs(self) -> AsyncRcsResourceWithStreamingResponse:
        return AsyncRcsResourceWithStreamingResponse(self._messaging.rcs)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from ..._base_client import AsyncPaginator, make_request_options
from ...types.porting_orders import phone_number_block_list_params, phone_number_block_create_params
from ...types.porting_orders.porting_phone_number_block import PortingPhoneNumberBlock
from ...types.porting_orders.phone_number_block_create_response import PhoneNumberBlockCreateResponse
from ...types.porting_orders.phone_number_block_delete_response import PhoneNumberBlockDeleteResponse

__all__ = ["PhoneNumberBlocksResource", "AsyncPhoneNumberBlocksResource"]


class PhoneNumberBlocksResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PhoneNumberBlocksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return PhoneNumberBlocksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PhoneNumberBlocksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return PhoneNumberBlocksResourceWithStreamingResponse(self)

    def create(
        self,
        porting_order_id: str,
        *,
        activation_ranges: Iterable[phone_number_block_create_params.ActivationRange],
        phone_number_range: phone_number_block_create_params.PhoneNumberRange,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PhoneNumberBlockCreateResponse:
        """
        Creates a new phone number block.

        Args:
          activation_ranges: Specifies the activation ranges for this porting phone number block. The
              activation range must be within the block range and should not overlap with
              other activation ranges.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not porting_order_id:
            raise ValueError(f"Expected a non-empty value for `porting_order_id` but received {porting_order_id!r}")
        return self._post(
            f"/porting_orders/{porting_order_id}/phone_number_blocks",
            body=maybe_transform(
                {
                    "activation_ranges": activation_ranges,
                    "phone_number_range": phone_number_range,
                },
                phone_number_block_create_params.PhoneNumberBlockCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PhoneNumberBlockCreateResponse,
        )

    def list(
        self,
        porting_order_id: str,
        *,
        filter: phone_number_block_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        sort: phone_number_block_list_params.Sort | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[PortingPhoneNumberBlock]:
        """
        Returns a list of all phone number blocks of a porting order.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[porting_order_id], filter[support_key], filter[status],
              filter[phone_number], filter[activation_status], filter[portability_status]

          sort: Consolidated sort parameter (deepObject style). Originally: sort[value]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not porting_order_id:
            raise ValueError(f"Expected a non-empty value for `porting_order_id` but received {porting_order_id!r}")
        return self._get_api_list(
            f"/porting_orders/{porting_order_id}/phone_number_blocks",
            page=SyncDefaultFlatPagination[PortingPhoneNumberBlock],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                        "sort": sort,
                    },
                    phone_number_block_list_params.PhoneNumberBlockListParams,
                ),
            ),
            model=PortingPhoneNumberBlock,
        )

    def delete(
        self,
        id: str,
        *,
        porting_order_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PhoneNumberBlockDeleteResponse:
        """
        Deletes a phone number block.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not porting_order_id:
            raise ValueError(f"Expected a non-empty value for `porting_order_id` but received {porting_order_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return self._delete(
            f"/porting_orders/{porting_order_id}/phone_number_blocks/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PhoneNumberBlockDeleteResponse,
        )


class AsyncPhoneNumberBlocksResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPhoneNumberBlocksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPhoneNumberBlocksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPhoneNumberBlocksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncPhoneNumberBlocksResourceWithStreamingResponse(self)

    async def create(
        self,
        porting_order_id: str,
        *,
        activation_ranges: Iterable[phone_number_block_create_params.ActivationRange],
        phone_number_range: phone_number_block_create_params.PhoneNumberRange,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PhoneNumberBlockCreateResponse:
        """
        Creates a new phone number block.

        Args:
          activation_ranges: Specifies the activation ranges for this porting phone number block. The
              activation range must be within the block range and should not overlap with
              other activation ranges.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not porting_order_id:
            raise ValueError(f"Expected a non-empty value for `porting_order_id` but received {porting_order_id!r}")
        return await self._post(
            f"/porting_orders/{porting_order_id}/phone_number_blocks",
            body=await async_maybe_transform(
                {
                    "activation_ranges": activation_ranges,
                    "phone_number_range": phone_number_range,
                },
                phone_number_block_create_params.PhoneNumberBlockCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PhoneNumberBlockCreateResponse,
        )

    def list(
        self,
        porting_order_id: str,
        *,
        filter: phone_number_block_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        sort: phone_number_block_list_params.Sort | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[PortingPhoneNumberBlock, AsyncDefaultFlatPagination[PortingPhoneNumberBlock]]:
        """
        Returns a list of all phone number blocks of a porting order.

        Args:
          filter:
              Consolidated filter parameter (deepObject style). Originally:
              filter[porting_order_id], filter[support_key], filter[status],
              filter[phone_number], filter[activation_status], filter[portability_status]

          sort: Consolidated sort parameter (deepObject style). Originally: sort[value]

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not porting_order_id:
            raise ValueError(f"Expected a non-empty value for `porting_order_id` but received {porting_order_id!r}")
        return self._get_api_list(
            f"/porting_orders/{porting_order_id}/phone_number_blocks",
            page=AsyncDefaultFlatPagination[PortingPhoneNumberBlock],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                        "sort": sort,
                    },
                    phone_number_block_list_params.PhoneNumberBlockListParams,
                ),
            ),
            model=PortingPhoneNumberBlock,
        )

    async def delete(
        self,
        id: str,
        *,
        porting_order_id: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> PhoneNumberBlockDeleteResponse:
        """
        Deletes a phone number block.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not porting_order_id:
            raise ValueError(f"Expected a non-empty value for `porting_order_id` but received {porting_order_id!r}")
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        return await self._delete(
            f"/porting_orders/{porting_order_id}/phone_number_blocks/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=PhoneNumberBlockDeleteResponse,
        )


class PhoneNumberBlocksResourceWithRawResponse:
    def __init__(self, phone_number_blocks: PhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

        self.create = to_raw_response_wrapper(
            phone_number_blocks.create,
        )
        self.list = to_raw_response_wrapper(
            phone_number_blocks.list,
        )
        self.delete = to_raw_response_wrapper(
            phone_number_blocks.delete,
        )


class AsyncPhoneNumberBlocksResourceWithRawResponse:
    def __init__(self, phone_number_blocks: AsyncPhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

        self.create = async_to_raw_response_wrapper(
            phone_number_blocks.create,
        )
        self.list = async_to_raw_response_wrapper(
            phone_number_blocks.list,
        )
        self.delete = async_to_raw_response_wrapper(
            phone_number_blocks.delete,
        )


class PhoneNumberBlocksResourceWithStreamingResponse:
    def __init__(self, phone_number_blocks: PhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

        self.create = to_streamed_response_wrapper(
            phone_number_blocks.create,
        )
        self.list = to_streamed_response_wrapper(
            phone_number_blocks.list,
        )
        self.delete = to_streamed_response_wrapper(
            phone_number_blocks.delete,
        )


class AsyncPhoneNumberBlocksResourceWithStreamingResponse:
    def __init__(self, phone_number_blocks: AsyncPhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

        self.create = async_to_streamed_response_wrapper(
            phone_number_blocks.create,
        )
        self.list = async_to_streamed_response_wrapper(
            phone_number_blocks.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            phone_number_blocks.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

from ..._types import SequenceNotStr

__all__ = ["BucketIDsParam"]


class BucketIDsParam(TypedDict, total=False):
    bucket_ids: Required[SequenceNotStr[str]]
    """
    List of
    [embedded storage buckets](https://developers.telnyx.com/api-reference/embeddings/embed-documents)
    to use for retrieval-augmented generation.
    """

    max_num_results: int
    """The maximum number of results to retrieve as context for the language model."""
